val vold : int
val vlat : int
val debug_heuristic : bool
val debug_litcount : bool
val debug_translation : bool
val debug_rewrite : bool
val debug_search : bool
val debug_add_clauses : bool
val debug_free_names : bool
val debug_leibeq : bool
val debug_Independent_refutation : bool
val debug_semantic : bool
val assert_freshness : bool
val assert_condition : bool
val result_print_search : bool
val result_print_translation : bool
val result_latex : bool
val result_statistic : bool
val result_coq : bool ref
val result_print_coq_type : bool
val pftrm_semantic_imp : bool
val pftrm_semantic_con : bool
val pftrm_semantic_mat_dec : bool
val pftrm_litcount : bool
val timeout : float ref
val pftrm_Timeout : bool
val pftrm_add_clauses : bool
val pftrm_Independent_refutation : bool
val pftrm_eager_rewrite : bool

val maxcoqproofsize : int

val result_isabellehol : bool ref
val max_isabellehol_proofsize : int
